// Copyright (C) [2009] [Robin und Detlef Wolf]
// This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.
// This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
// You should have received a copy of the GNU General Public License along with this program; if not, see <http://www.gnu.org/licenses/>.

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;

@SuppressWarnings("serial")
public class VRFrame extends JFrame {

	private VRModel m ;
	
  public VRFrame(VRModel m) {
  	this.m = m ;
  	if (!m.isApplet)
      setDefaultCloseOperation(EXIT_ON_CLOSE) ;
    setTitle("Vektorrennen Version 2010-02-02") ;
    setLayout(new BorderLayout());
    
    JMenuBar mb = new JMenuBar(); 
    GameMenu gameMenu = new GameMenu(this); 
    mb.add(gameMenu);
    TrackMenu trackMenu = new TrackMenu(this); 
    mb.add(trackMenu);
    // OptionsMenu optionsMenu = new OptionsMenu(this); 
    // mb.add(optionsMenu);
    HelpMenu helpMenu = new HelpMenu(this); 
    mb.add(helpMenu);
    setJMenuBar(mb);
    
    add(new VRBahn(m), BorderLayout.CENTER) ;
    add(new VRStatus(m), BorderLayout.SOUTH) ;
    
  }

  private void exit() { 
    setVisible(false); // hide the Frame 
    dispose(); // tell windowing system to free resources 
    System.exit(0); // exit 
  } 

  class GameMenu extends JMenu implements ActionListener { 
    VRFrame mw;  // who owns us? 
    public GameMenu(VRFrame f) { 
      super("Spiel"); 
      mw = f; 
      JMenuItem mi; 
      add(mi = new JMenuItem("Nochmal spielen")); 
      mi.addActionListener(this); 
      add(mi = new JMenuItem("Beenden")); 
      mi.addActionListener(this); 
    } 
    
    public void actionPerformed(ActionEvent e) { 
      String item = e.getActionCommand(); 
      if (item.equals("Beenden"))  
        mw.exit(); 
      else if (item.equals("Nochmal spielen")) {
      	m.playAgain() ;
      }
      else
        System.out.println("PROBLEM: Selected SpielMenu " + item); 
    } 
  } 

  class TrackMenu extends JMenu implements ActionListener { 
    VRFrame mw;  // who owns us? 
        
    public TrackMenu(VRFrame f) { 
      super("Strecke"); 
      mw = f; 
      JMenuItem mi; 
      add(mi = new JMenuItem("Lade Strecke \"Hallo\"")); 
      mi.addActionListener(this); 
      add(mi = new JMenuItem("Lade Strecke \"Enge Kurven\"")); 
      mi.addActionListener(this); 
      add(mi = new JMenuItem("Lade Strecke \"Vollgas\"")); 
      mi.addActionListener(this); 
      
      add(mi = new JMenuItem("Strecke ausbauen")); 
      mi.addActionListener(this); 
      
      add(mi = new JMenuItem("Neue Strecke bauen")); 
      mi.addActionListener(this); 

      add(mi = new JMenuItem("Laden von Datei ...")); 
      mi.addActionListener(this); 
      mi.setEnabled(!m.isApplet) ;
      
      add(mi = new JMenuItem("Speichern in Datei ...")); 
      mi.addActionListener(this); 
      mi.setEnabled(!m.isApplet) ;
    } 
    
    public void actionPerformed(ActionEvent e) { 
      String item = e.getActionCommand(); 
      if (item.equals("Lade Strecke \"Hallo\"")) {  
      	VRFile vrf = new VRFile(mw) ;
      	vrf.loadFile(mw.m, VRModel.DEFAULT_TRACK) ;
      }
      else if (item.equals("Lade Strecke \"Enge Kurven\"")) {  
      	VRFile vrf = new VRFile(mw) ;
      	vrf.loadFile(mw.m, "tracks/vrstandard_engekurven.txt") ;
      }
      else if (item.equals("Lade Strecke \"Vollgas\"")) {  
      	VRFile vrf = new VRFile(mw) ;
      	vrf.loadFile(mw.m, "tracks/vrstandard_einfach.txt") ;
      }
      else if (item.equals("Neue Strecke bauen")) {  
        m.clearTrack() ;
      }
      else if (item.equals("Strecke ausbauen")) {
      	m.setRaceMode(false) ;    
      }
      else if (item.equals("Laden von Datei ...")) {
      	VRFile vrf = new VRFile(mw) ;
      	vrf.loadFile(mw.m) ;
      }
      else if (item.equals("Speichern in Datei ...")) {
      	VRFile vrf = new VRFile(mw) ;
      	vrf.saveFile(mw.m) ;
      }
      else
        System.out.println("PROBLEM: Selected TrackMenu " + item); 
    } 
  } 

//  for future expansion:
//  class OptionsMenu extends JMenu implements ActionListener { 
//    VRFrame mw;  // who owns us? 
//    public OptionsMenu(VRFrame f) { 
//      super("Options"); 
//      mw = f; 
//      ButtonGroup group = new ButtonGroup();
//      JRadioButtonMenuItem mi ;
//
//      add(mi = new JRadioButtonMenuItem("legal", true)); 
//      mi.addActionListener(this); 
//      group.add(mi);
//
//      add(mi = new JRadioButtonMenuItem("weniger legal")); 
//      mi.addActionListener(this); 
//      group.add(mi);
//
//      add(mi = new JRadioButtonMenuItem("egal")); 
//      mi.addActionListener(this); 
//      group.add(mi);
//    } 
//    
//    public void actionPerformed(ActionEvent e) { 
//      System.out.println("ActionEvent " + e);
//      String s = e.getActionCommand() ;
//      if (s.equals("legal")) {  
//      	System.out.println("legal");
//      }
//      else if (s.equals("weniger legal")) {
//      	
//      }
//      else if (s.equals("egal")) {
//      	
//      }
//      else
//        System.out.println("PROBLEM: Selected OptionsMenu " + s); 
//    } 
//  } 

  class HelpMenu extends JMenu implements ActionListener { 
    VRFrame mw;  // who owns us? 
    public HelpMenu(VRFrame f) { 
      super("Hilfe"); 
      mw = f; 
      JMenuItem mi; 
      add(mi = new JMenuItem("Hilfe")); 
      mi.addActionListener(this); 
      add(mi = new JMenuItem("ber ...")); 
      mi.addActionListener(this); 
    } 
    
    public void actionPerformed(ActionEvent e) { 
      String item = e.getActionCommand(); 
      System.out.println("actionperformed" + e);
      if (item.equals("Hilfe")) {  
        VRHelp help = new VRHelp() ;
        help.pack();
      	help.setVisible(true) ;
  	    help.toFront() ;
      }
      else if (item.equals("ber ...")) {
      	JOptionPane.showMessageDialog(mw, 
      			"Robin und Detlef Wolf, 2009.\n"
      			+ "Dieses Programm ist \"Freie Software\". "
      			+ "Lizenz: GPL, siehe http://www.gnu.org/licenses/\n"
      			+ "Quelltext abrufbar unter http://www.wolfol.de\n"
      			, "ber dieses Programm", JOptionPane.PLAIN_MESSAGE) ; 
      }
      else
        System.out.println("PROBLEM: Selected HelpMenu " + item); 
    } 
  } 

  
}
